@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -179,7 +179,7 @@ sub _process {
 sub _make_table {
     my %args = @_;
 
-    my @cdata = ( _caption( %args ), _colgroup( %args ) );
+    my @cdata = ( _tag( %args, tag => 'caption' ) || (), _colgroup( %args ) );
 
     if ($args{tgroups}) {
 
@@ -215,20 +215,19 @@ sub _make_table {
     return $args{_auto}->tag( tag => 'table', attr => $args{table}, cdata => \@cdata );
 }
 
-sub _caption {
+sub _tag {
     my %args = @_;
 
-    my $caption;
-
-    if (ref($args{caption}) eq 'HASH') {
-        (my $cdata) = keys %{ $args{caption} };
-        (my $attr)  = values %{ $args{caption} };
-        $caption = { tag => 'caption', attr => $attr, cdata => $cdata };
-    } elsif (defined $args{caption} ) {
-        $caption = { tag => 'caption', cdata => $args{caption} };
+    my $tag;
+    if (ref($args{ $args{tag} }) eq 'HASH') {
+        (my $cdata) = keys %{ $args{ $args{tag} } };
+        (my $attr)  = values %{ $args{ $args{tag} } };
+        $tag = { tag => $args{tag}, attr => $attr, cdata => $cdata };
+    } elsif (defined $args{ $args{tag} } ) {
+        $tag = { tag => $args{tag}, cdata => $args{ $args{tag} } };
     } 
     
-    return $caption ? $caption : ();
+    return $tag;
 }
 
 sub _colgroup {
@@ -384,7 +383,7 @@ Procedural interface:
 Generate HTML tables with ease (HTML4, XHTML and HTML5). Generate
 portrait, landscape and other rotated views, Handsontable tables, HTML
 calendars, checkerboard patterns, games such as sudoku, banners and mazes,
-and create animations of cell values and backgrounds via supplied jQuery.
+and create animations of cell values and backgrounds via jQuery.
 Rewrap existing tables from Excel, HTML, JSON, CSV and YAML files.
 
 =head1 CLI TOOLS
@@ -438,49 +437,58 @@ generating methods below:
 
 =item * C<generate( %params )>
 
+Generate an HTML table with headings positioned at the top.
+
+  print $generator->generate();
+
 =item * C<portrait( %params )>
 
+Alias for C<generate()>.
+
+  print $generator->portrait();
+
 =item * C<north( %params )>
 
-These three methods all generate an HTML table with headings positioned at the top.
+Alias for C<generate()>.
+
+  print $generator->north();
 
 =for html
 <table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
 
-  print $generator->generate();
-  print $generator->portrait();
-  print $generator->north();
-
 =item * C<landscape( %params )>
 
+Generate an HTML table with headings positioned at the left.
+
+  print $generator->landscape();
+
 =item * C<west( %params )>
 
-These two methods generate an HTML table with headings positioned at the left.
+Alias for C<landscape>.
+
+  print $generator->west();
 
 =for html
 <table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
 
-  print $generator->landscape();
-  print $generator->west();
-
 =item * C<south( %params )>
 
-This method generates an HTML table with headings positioned at the bottom.
+Generate an HTML table with headings positioned at the bottom.
+
+  print $generator->south();
 
 =for html
 <table style="border: 1px dashed #A0A0A0"><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr></table>
 
-  print $generator->south();
-
 =item * C<east( %params )>
 
 This method generates an HTML table with headings positioned at the right.
 
+  print $generator->east();
+
 =for html
 <table style="border: 1px dashed #A0A0A0"><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr></table>
 
-  print $generator->east();
-
 =back
 
 For most cases, C<portrait> (headings at top)
@@ -575,17 +583,23 @@ counter-clockwise for negative values. Default to 0:
 headers at top.  90: headers at right. 180: headers at bottom.
 270: headers at left. To achieve landscape, use -270.
 
-=item * C<flip: 0 or 1>
+  theta => -270
 
-Flips table horizontally from the perspective of the headings
-"row" by negating the value of C<theta>.
+=item * C<flip>
 
-=item * C<pinhead: 0 or 1>
+Boolean Flips table horizontally from the perspective of
+the headings "row" by negating the value of C<theta>.
 
-Works in conjunction with C<theta> to ensure reporting
+  flip => 1
+
+=item * C<pinhead>
+
+Boolean. Works in conjunction with C<theta> to ensure reporting
 readability. Without it, C<south()> and C<east()> would
 have data cells arranged in reverse order.
 
+  pinhead => 1
+
 =item * C<indent>
 
 Render the table with nested indentation. Defaults to
@@ -609,7 +623,7 @@ repetition operator to the value of C<indent> 4 times.
 
 =item * C<encode>
 
-Encode HTML entities. Boolean. Defaults to false, which produces no encoding.
+Boolean. Encode HTML entities. Defaults to false, which produces no encoding.
 If set to true without further specifying a value for C<encodes> (see below),
 will encode all control chars, high bit chars and '<', '&', '>', ''' and '"'.
 
@@ -629,17 +643,21 @@ Set value to C<undef> to avoid any substitutions.
 
   empty => '&#160;'
 
-=item * C<tgroups: 0, 1 or 2>
+=item * C<tgroups>
 
-Group table rows into <thead>, <tbody> and <tfoot> sections.
+Integer. Group table rows into <thead>, <tbody> and <tfoot> sections.
 
 When C<tgroups> is set to 1, the <tfoot> section is
 omitted. The last row of the data is found at the end
 of the <tbody> section instead. (loose)
 
+  tgroups => 1
+
 When C<tgroups> is set to 2, the <tfoot> section is found
 in between the <thead> and <tbody> sections. (strict)
 
+  tgroups => 2
+
 =item * C<group>
 
 Will chunk body rows into tbody groups of size C<group>.
@@ -648,24 +666,32 @@ Will chunk body rows into tbody groups of size C<group>.
 
 Currently only accepts integers (not column names).
 
-=item * C<cache: 0 or 1>
+=item * C<cache>
 
-Preserve data after it has been processed (and loaded).
+Boolean. Preserve data after it has been processed (and loaded).
 Useful for loading data from files only once.
 
-=item * C<matrix: 0 or 1>
+  cache => 1
 
-Render the headings row with only <td> tags, no <th> tags.
+=item * C<matrix>
 
-=item * C<headless: 0 or 1>
+Boolean. Render the headings row with only <td> tags, no <th> tags.
 
-Render the table with without the headings row at all. 
+  matrix => 1
+
+=item * C<headless>
+
+Boolean. Render the table with without the headings row at all. 
 The first row after the headings is still C<-r1>, and
 any configuration to C<headings> or C<-r0> will be discarded.
 
-=item * C<scroll: 0 or 1>
+  headless => 1
 
-Scrolls the table cells. See L<Spreadsheet::HTML::Presets::Scroll>.
+=item * C<scroll>
+
+Boolean. Scrolls the table cells. See L<Spreadsheet::HTML::Presets::Scroll>.
+
+  scroll => 1
 
 =item * C<headings>
 
@@ -686,12 +712,14 @@ C<-r0>, it could be considered as a dynamic parameter. Be
 careful not to prepend a dash to C<headings> ... only dynamic
 parameters use leading dashes.
 
-=item * C<sorted_attrs: 0 or 1>
+=item * C<sorted_attrs>
 
-This is useful for ensuring that attributes within tags are
+Boolean. This is useful for ensuring that attributes within tags are
 rendered in alphabetical ordering, for consistancy. You will
 most likely never need this feature.
 
+  sorted_attrs
+
 =back
 
 =head2 DYNAMIC PARAMETERS
@@ -763,18 +791,32 @@ share the names of the actual HTML table tags.
 
 =item * C<table>
 
+Hash ref. Apply these attributes to the specified tag.
+
+  table => { border => 1 }
+
 =item * C<thead>
 
+Hash ref. Apply these attributes to the specified tag.
+
+  thead => { class => 'heading' }
+
 =item * C<tfoot>
 
+Hash ref. Apply these attributes to the specified tag.
+
+  tfoot => { class => 'footing' }
+
 =item * C<tbody>
 
+Hash ref. Apply these attributes to the specified tag.
+
+  tbody => { class => 'body' }
+
 =item * C<tr>
 
 Hash ref. Apply these attributes to the specified tag.
 
-  table => { class => 'spreadsheet' }
-
   tr => { style => { background => [qw( color1 color2 )]' } }
 
 Does not apply to <tr> groups found within <thead> or <tfoot>.
@@ -782,14 +824,23 @@ Does not apply to <tr> groups found within <thead> or <tfoot>.
 
 =item * C<th>
 
-=item * C<td>
+Hash ref, sub ref or array ref containing either.
 
-<th> and <td> are the only Tag Parameters that may
-additionally accept callback subroutines.
+  th => { class => 'heading' }
 
   th => sub { uc shift }
 
-  td => [ sub { uc shift }, { class => 'foo' } ]
+  th => [ sub { uc shift }, { class => 'heading' } ]
+
+=item * C<td>
+
+Hash ref, sub ref or array ref containing either.
+
+  td => { class => 'cell' }
+
+  td => sub { uc shift }
+
+  td => [ sub { uc shift }, { class => 'cell' } ]
 
 =item * C<caption>
 
@@ -823,53 +874,92 @@ tags within a colgroup tag. Same usage as C<colgroup>.
 When C<tgroups> is 1 or 2, this tag parameter is available to control
 the attributes of the <tr> tag within the <thead> group.
 
+  'tr.head' => { class => 'heading-row' }
+
 =item * C<tfoot.tr>
 
 When C<tgroups> is 2, this tag parameter is available to control
 the attributes of the <tr> tag within the <tfoot> group.
 
+  'tr.foot' => { class => 'footing-row' }
+
 =back
 
 =head2 PRESETS
 
 The following presets are availble for creating tables that can be used
-with little to no additional coding.
+with little to no additional coding. All preset methods accept all of the
+above mentioned parameters (%params) in addition to those specific to themselves.
 
 =over 4
 
 =item * C<layout( %params )>
 
+Generate layout tables.
+
 =item * C<list( ordered, col, row, %params )>
 
-=item * C<select( col, row, labels, texts, values, placeholder, label, %params )>
+Generate <ol> and <ul> list.
 
-=item * C<handson( handsonjs, jquery, css, %params )>
+=item * C<select( col, row, values, selected, placeholder, optgroup, label, %params )>
 
-=item * C<banner( on, off, text, font, %params )>
+Generate <select> form elements.
 
-=item * C<calendar( month, year, %params )>
+=item * C<handson( args, jquery, handsonjs, css, %params )>
 
-=item * C<scroll( fgdirection, bgdirection, jquery, %params )>
-
-=item * C<conway( on, off, fade, jquery, %params )>
-
-=item * C<calculator( jquery, %params )>
+Generate Handsontable tables. (Excel like interface for browsers.)
 
 =item * C<checkerboard( colors, %params )>
 
-=item * C<sudoku( blanks, attempts, %params )>
+Generate checkerboard patterns in cell backgrounds.
 
-=item * C<maze( on, off, fill, %params )>
+=item * C<banner( on, off, text, font, dir, emboss, %params )>
 
-=item * C<chess( %params )>
+Generate banners via Text::FIGlet.
 
-=item * C<checkers( %params )>
+=item * C<scroll( fgdirection, fx, fy, bgdirection, bx, by, interval, jquery, %params )>
 
-=item * C<tictactoe( %params )>
+Scroll table cell foregrounds and backgrounds.
 
-=item * C<beadwork( %params )>
+=item * C<animate( fgdirection, fx, fy, bgdirection, bx, by, interval, jquery, %params )>
 
-=item * C<animate( %params )> - Deprecated: use C<scroll()> instead.
+Deprecated. Use C<scroll()> instead.
+
+=item * C<calendar( month, year, today, -day, %params )>
+
+Generate calendars.
+
+=item * C<calculator( jquery, %params )>
+
+Generate a simple HTML table calculator.
+
+=item * C<beadwork( preset, art, map, bgcolor, %params )>
+
+Turn cell backgrounds into 8-bit pixel art.
+
+=item * C<conway( on, off, colors, fade, interval, jquery, %params )>
+
+Turn cell backgrounds into Conway's game of life.
+
+=item * C<sudoku( blanks, attempts, jquery, %params )>
+
+Generate 9x9 HTML table sudoku boards.
+
+=item * C<maze( on, off, %params )>
+
+Generates a static maze.
+
+=item * C<tictactoe( jquery, %params )>
+
+Creates a playable Tic-Tac-Toe game board.
+
+=item * C<checkers( on, off, jquery, %params )>
+
+Creates a NON playable Checkers game board.
+
+=item * C<chess( on, off, jquery, jqueryui, %params )>
+
+Creates a NON playable Chess game board.
 
 =back
 
